<?php
/**
* PHP Exif Tool Liberary
*
*/
require __DIR__ . '/autoload.php';
use Monolog\Logger;
use PHPExiftool\Reader;
use PHPExiftool\Driver\Value\ValueInterface;
use PHPExiftool\Writer;
use PHPExiftool\Driver\Metadata\Metadata;
use PHPExiftool\Driver\Metadata\MetadataBag;
use PHPExiftool\Driver\Tag\IPTC\ObjectName;
use PHPExiftool\Driver\Value\Mono;
use PHPExiftool\Driver\Tag\XMPPhotoshop\City;
use PHPExiftool\Driver\Tag\XMPXmp\Keywords;
use PHPExiftool\Driver\Tag\IPTC\Credit;
use PHPExiftool\Driver\Tag\XMPPlus\LicensorURL;
use PHPExiftool\Driver\Tag\XMPPlus\ImageCreatorName;
use PHPExiftool\Driver\Tag\XMPPlus\ImageCreatorID;
use PHPExiftool\Driver\Tag\XMPPlus\ImageCreatorImageID;
use PHPExiftool\Driver\Tag\XMPPhotoshop\Credit as XMPCredit;
use PHPExiftool\Driver\Tag\XMPDc\Creator;
use PHPExiftool\Driver\Tag\IPTC\ByLine;
use PHPExiftool\Driver\Tag\IPTC\ByLineTitle;
use PHPExiftool\Driver\Tag\XMPXmpRights\WebStatement;
use PHPExiftool\Driver\Tag\XMPDc\Title;
use PHPExiftool\Driver\Tag\IPTC\Headline as IPTC_Headline;
use PHPExiftool\Driver\Tag\XMPDc\Description;
use PHPExiftool\Driver\Tag\IPTC\CaptionAbstract;
use PHPExiftool\Driver\Tag\XMPDc\Rights;
use PHPExiftool\Driver\Tag\IPTC\CopyrightNotice;
use PHPExiftool\Driver\Tag\XMPPhotoshop\Headline;
use PHPExiftool\Driver\Tag\XMPDc\Subject;
use PHPExiftool\Driver\Tag\IPTC\Keywords as IPTC_Keywords;
use PHPExiftool\Driver\Tag\XMPPlus\CopyrightOwnerName;
use PHPExiftool\Driver\Tag\XMPPlus\CopyrightOwnerImageID;
use PHPExiftool\Driver\Tag\XMPPlus\CopyrightOwnerID;
use PHPExiftool\Driver\Tag\XMPPlus\CopyrightOwner;
use PHPExiftool\Driver\Tag\XMPPlus\CopyrightStatus;
use PHPExiftool\Driver\Tag\XMPPlus\PLUSVersion;
use PHPExiftool\Driver\Tag\XMPIptcExt\RegistryID;
use PHPExiftool\Driver\Tag\XMPIptcExt\RegistryItemID;
use PHPExiftool\Driver\Tag\XMPIptcExt\RegistryEntryRole;
use PHPExiftool\Driver\Tag\XMPIptcExt\RegistryOrganisationID;
use PHPExiftool\Driver\Tag\XMPPlus\LicensorName;
use PHPExiftool\Driver\Tag\XMPPlus\LicenseID;
use PHPExiftool\Driver\Tag\XMPPlus\LicensorEmail;
use PHPExiftool\Driver\Tag\XMPPlus\LicensorImageID;
use PHPExiftool\Driver\Tag\XMPPlus\TermsAndConditionsURL;
use PHPExiftool\Driver\Tag\XMPPlus\MediaConstraints;
use PHPExiftool\Driver\Tag\XMPPlus\MediaSummaryCode;
use PHPExiftool\Driver\Tag\XMPPlus\LicenseeID;
use PHPExiftool\Driver\Tag\XMPPlus\LicenseeTransactionID;
use PHPExiftool\Driver\Tag\XMPPlus\LicensorTransactionID;
use PHPExiftool\Driver\Tag\XMPPlus\LicenseTransactionDate;
use PHPExiftool\Driver\Tag\XMPPlus\LicenseStartDate;
use PHPExiftool\Driver\Tag\XMPPlus\LicenseeName;
use PHPExiftool\Driver\Tag\XMPPlus\EndUserName;
use PHPExiftool\Driver\Tag\XMPPlus\EndUserID;
use PHPExiftool\Driver\Tag\XMPPlus\LicenseeImageID;
use PHPExiftool\Driver\Tag\XMPPlus\FileNameAsDelivered;
use PHPExiftool\Driver\Tag\XMPPlus\ImageFileConstraints;
use PHPExiftool\Driver\Tag\XMPPlus\CreditLineRequired;
use PHPExiftool\Driver\Tag\XMPPlus\LicensorID;
use PHPExiftool\Driver\Tag\XMPPlus\OtherConditions;
use PHPExiftool\Driver\Tag\XMPPhotoshop\Source;
use PHPExiftool\Driver\Tag\IPTC\Source as IPTC_Source;
use PHPExiftool\Driver\Tag\XMPPhotoshop\CaptionWriter;
use PHPExiftool\Driver\Tag\IPTC\WriterEditor;
use PHPExiftool\Driver\Tag\IFD0\ModifyDate;
use PHPExiftool\Driver\Tag\ExifIFD\ExifVersion;
use PHPExiftool\Driver\Tag\ExifIFD\DateTimeOriginal;
use PHPExiftool\Driver\Tag\ExifIFD\CreateDate;
use PHPExiftool\Driver\Tag\ExifIFD\OffsetTimeOriginal;
use PHPExiftool\Driver\Tag\ExifIFD\OffsetTimeDigitized;
//use PHPExiftool\Driver\Tag\File\ImageWidth;
//use PHPExiftool\Driver\Tag\File\ImageHeight;
use PHPExiftool\Driver\Tag\ExifIFD\OffsetTime;
use PHPExiftool\Driver\Tag\ExifIFD\ComponentsConfiguration;
use PHPExiftool\Driver\Tag\ExifIFD\FlashpixVersion;
use PHPExiftool\Driver\Tag\ExifIFD\ColorSpace;
/**
 * CLink Exif Tool Metadata Writter
 * 
 * @param string image_path image path
 * @param array data metadata
 * @param integer attachment_if attachment id
 * 
 */
function wpclink_metadata_writter($image_path = false, $data = array(), $attachment_id = false, $scaled_only = false, $cache_id = 0){
	
	
	$logger = new Logger('exiftool');
	$writer = Writer::create($logger);
	$bag = new MetadataBag();
	$metadata = array();
	
	
	// Title
	if(isset($data['title'])){
		
		// XMP
		$bag->add(new Metadata(new Title(), new Mono($data['title'])));
		$metadata["XMP-dc:Title"] = $data['title'];
		
		// IPTC
		$bag->add(new Metadata(new ObjectName(), new Mono($data['title'])));
		$metadata["IPTC:ObjectName"] = $data['title'];
		
	}
	// Headline
	if(isset($data['image_title'])){
		// XMP
		$bag->add(new Metadata(new Headline(), new Mono($data['image_title'])));
		$metadata["XMP-photoshop:Headline"] = $data['image_title'];
		
		// IPTC
		$bag->add(new Metadata(new IPTC_Headline(), new Mono($data['image_title'])));
		$metadata["IPTC:Headline"] = $data['image_title'];
	}
	// Image Creator ID
	if(isset($data['image_creator_ID'])){
		
		// XMP
		$bag->add(new Metadata(new ImageCreatorID(), new Mono($data['image_creator_ID'])));
		$metadata["XMP-plus:ImageCreatorID"] = $data['image_creator_ID'];
		
		$bag->add(new Metadata(new CopyrightOwnerID(), new Mono($data['image_creator_ID'])));
		$metadata["XMP-plus:CopyrightOwnerID"] = $data['image_creator_ID'];
	}
	// Image Creator Name
	if(isset($data['image_creator_name'])){
		
		// XMP
		$bag->add(new Metadata(new ImageCreatorName(), new Mono($data['image_creator_name'])));
		$metadata["XMP-plus:ImageCreatorName"] = $data['image_creator_name'];
		
		$bag->add(new Metadata(new CopyrightOwnerName(), new Mono($data['image_creator_name'])));
		$metadata["XMP-plus:CopyrightOwnerName"] = $data['image_creator_name'];
	
	}
	// Creation ID
	if(isset($data['creation_ID'])){
		
		// XMP
		$bag->add(new Metadata(new ImageCreatorImageID(), new Mono($data['creation_ID'])));
		$metadata["XMP-plus:ImageCreatorImageID"] = $data['creation_ID'];
		
		$bag->add(new Metadata(new CopyrightOwnerImageID(), new Mono($data['creation_ID'])));
		$metadata["XMP-plus:CopyrightOwnerImageID"] = $data['creation_ID'];
		
		$bag->add(new Metadata(new CopyrightStatus(), new Mono("Protected")));
		$metadata["XMP-plus:CopyrightStatus"] = "CS-PRO";
		
		$bag->add(new Metadata(new PLUSVersion(), new Mono('1.2.2')));
		$metadata["XMP-plus:PLUSVersion"] = "1.2.2";
		
	}
	// Registery Item ID
	if(isset($data['registry_item_ID'])){
		
		$bag->add(new Metadata(new RegistryOrganisationID(), new Mono('https://clink.id')));
		$metadata["XMP-iptcExt:RegistryOrganisationID"] = "https://clink.id";
		
		$bag->add(new Metadata(new RegistryItemID(), new Mono($data['registry_item_ID'])));
		$metadata["XMP-iptcExt:RegistryItemID"] = $data['registry_item_ID'];
		
		$bag->add(new Metadata(new RegistryEntryRole(), new Mono('Handle')));
		$metadata["XMP-iptcExt:RegistryEntryRole"] = "Handle";
		
	}
	// Registery Item ID at 1
	if(isset($data['registry_item_IDat1'])){
		
		$bag->add(new Metadata(new RegistryOrganisationID(), new Mono('https://clink.id')));
		$metadata["XMP-iptcExt:RegistryOrganisationID"] = "https://clink.id";
		
		// Cordra
		$bag->add(new Metadata(new RegistryItemID(), new Mono($data['registry_item_IDat1'])));
		$metadata["XMP-iptcExt:RegistryItemID"] = $data['registry_item_IDat1'];
		
		$bag->add(new Metadata(new RegistryEntryRole(), new Mono('Handle')));
		$metadata["XMP-iptcExt:RegistryEntryRole"] = "Handle";
	}
	if(isset($data['registry_item_IDat2'])){
		$bag->add(new Metadata(new RegistryOrganisationID(), new Mono('https://clink.id')));
		$metadata["XMP-iptcExt:RegistryOrganisationID"] = "https://clink.id";
		
		// ISCC
		$bag->add(new Metadata(new RegistryItemID(), new Mono($data['registry_item_IDat2'])));
		$metadata["XMP-iptcExt:RegistryItemID"] = $data['registry_item_IDat2'];
		
		
		$bag->add(new Metadata(new RegistryEntryRole(), new Mono('ISCC')));
		$metadata["XMP-iptcExt:RegistryEntryRole"] = "ISCC";
		
	}
	// Licensor Display Name
	if(isset($data['licensor_display_name'])){
		$bag->add(new Metadata(new LicensorName(), new Mono($data['licensor_display_name'])));
		$metadata["XMP-plus:LicensorName"] = $data['licensor_display_name'];
	}
	// Caption Writter
	if(isset($data['caption_writer'])){
		$bag->add(new Metadata(new CaptionWriter(), new Mono($data['caption_writer'])));
		$metadata["XMP-photoshop:CaptionWriter"] = $data['caption_writer'];
		
		$bag->add(new Metadata(new WriterEditor(), new Mono($data['caption_writer'])));
		$metadata["IPTC:Writer-Editor"] = $data['caption_writer'];
	}
	// Other Condition
	if(isset($data['linked_other_conditions'])){
		$bag->add(new Metadata(new OtherConditions(), new Mono(str_replace(",",", ",$data['linked_other_conditions']))));
		$metadata["XMP-plus:OtherConditions"] = str_replace(",",", ",$data['linked_other_conditions']);
	}
	// Licensor Email
	if(isset($data['licensor_email'])){
		$bag->add(new Metadata(new LicensorEmail(), new Mono('Email (Protected)')));
		$metadata["XMP-plus:LicensorEmail"] = "Email (Protected)";
	}
	// Licensor Image ID
	if(isset($data['licensor_image_ID'])){
		$bag->add(new Metadata(new LicensorImageID(), new Mono($data['licensor_image_ID'])));
		$metadata["XMP-plus:LicensorImageID"] = $data['licensor_image_ID'];
	}
	// Licensor ID
	if(isset($data['licensor_ID'])){
		$bag->add(new Metadata(new LicensorID(), new Mono($data['licensor_ID'])));
		$metadata["XMP-plus:LicensorID"] = $data['licensor_ID'];
	}
	// Terms and Condition URL
	if(isset($data['termsandcondition_url'])){
		$bag->add(new Metadata(new TermsAndConditionsURL(), new Mono($data['termsandcondition_url'])));
		$metadata["XMP-plus:TermsAndConditionsURL"] = $data['termsandcondition_url'];
	}
	// Media Constraints
	if(isset($data['mediaconstraints'])){
		$bag->add(new Metadata(new MediaConstraints(), new Mono($data['mediaconstraints'])));
		$metadata["XMP-plus:MediaConstraints"] = $data['mediaconstraints'];
	}
	// Image File Constraints
	if(isset($data['imagefileconstraints'])){
		$bag->add(new Metadata(new ImageFileConstraints(), new Mono("Maintain Metadata")));
		$metadata["XMP-plus:ImageFileConstraints"] = "IF-MMD";
	}
	// Credit Line Required
	if(isset($data['creditlinerequired'])){
		$bag->add(new Metadata(new CreditLineRequired(), new Mono("Credit on Image")));
		$metadata["XMP-plus:CreditLineRequired"] = "CR-COI";
	}
	// Image File Contraints
	if(isset($data['linked_ImageFileConstraints'])){
		$bag->add(new Metadata(new ImageFileConstraints(), new Mono($data['linked_ImageFileConstraints'])));
		$metadata["XMP-plus:ImageFileConstraints"] = $data['linked_ImageFileConstraints'];
		
		$bag->add(new Metadata(new ImageFileConstraints(), new Mono("Maintain File Name")));
		$metadata["XMP-plus:ImageFileConstraints"] = $metadata["XMP-plus:ImageFileConstraints"].' ; '."IF-MFN";
	}
	// Credit Line Required
	if(isset($data['linked_CreditLineRequired'])){
		$bag->add(new Metadata(new CreditLineRequired(), new Mono($data['linked_CreditLineRequired'])));
		$metadata["XMP-plus:CreditLineRequired"] = $data['linked_CreditLineRequired'];
	}
	// Copyright Status
	if(isset($data['linked_CopyrightStatus'])){
		$bag->add(new Metadata(new CopyrightStatus(), new Mono($data['linked_CopyrightStatus'])));
		$metadata["XMP-plus:CopyrightStatus"] = $data['linked_CopyrightStatus'];
	}
	// Media Summary Code
	if(isset($data['mediasummarycode'])){
		$bag->add(new Metadata(new MediaSummaryCode(), new Mono($data['mediasummarycode'])));
		$metadata["XMP-plus:MediaSummaryCode"] = "1IAC";		
	}
	// Licensee and Licensor IDs
	if(isset($data['right_transaction_ID'])){
		
		$bag->add(new Metadata(new LicenseID(), new Mono($data['right_transaction_ID'])));
		$metadata["XMP-plus:LicenseID"] = $data['right_transaction_ID'];
		
		$bag->add(new Metadata(new LicenseeTransactionID(), new Mono($data['right_transaction_ID'])));
		$metadata["XMP-plus:LicenseeTransactionID"] = $data['right_transaction_ID'];
		
		$bag->add(new Metadata(new LicensorTransactionID(), new Mono($data['right_transaction_ID'])));
		$metadata["XMP-plus:LicensorTransactionID"] = $data['right_transaction_ID'];
	}
	// License Transation Date and Start Time
	if(isset($data['right_transaction_time'])){
		
		$bag->add(new Metadata(new LicenseTransactionDate(), new Mono($data['right_transaction_time'])));
		$bag->add(new Metadata(new LicenseStartDate(), new Mono($data['right_transaction_time'])));
	}
	// Licensee Name
	if(isset($data['licensee_display_name'])){
		
		$bag->add(new Metadata(new LicenseeName(), new Mono($data['licensee_display_name'])));
		$metadata["XMP-plus:LicenseeName"] = $data['licensee_display_name'];
		
		$bag->add(new Metadata(new EndUserName(), new Mono($data['licensee_display_name'])));
		$metadata["XMP-plus:EndUserName"] = $data['licensee_display_name'];
	}
	// Licensee ID
	if(isset($data['licensee_ID'])){
		$bag->add(new Metadata(new LicenseeID(), new Mono($data['licensee_ID'])));
		$metadata["XMP-plus:LicenseeID"] = $data['licensee_ID'];
		
		$bag->add(new Metadata(new EndUserID(), new Mono($data['licensee_ID'])));
		$metadata["XMP-plus:EndUserID"] = $data['licensee_ID'];
	}
	// Licensee Image ID
	if(isset($data['linked_creation_ID'])){
		$bag->add(new Metadata(new LicenseeImageID(), new Mono($data['linked_creation_ID'])));
		$metadata["XMP-plus:LicenseeImageID"] = $data['linked_creation_ID'];
	}
	// Photoshop Source	
	if(isset($data['photoshop_source'])){
		$bag->add(new Metadata(new Source(), new Mono($data['photoshop_source'])));
		$metadata["XMP-photoshop:Source"] = $data['photoshop_source'];
		
		$bag->add(new Metadata(new IPTC_Source(), new Mono($data['photoshop_source'])));
		$metadata["IPTC:Source"] = $data['photoshop_source'];
	}
	// Description
	if(isset($data['description'])){
		// XMP
		$bag->add(new Metadata(new Description(), new Mono($data['description'])));
		$metadata["XMP-dc:Description"] = $data['description'];
		
		// IPTC
		$bag->add(new Metadata(new CaptionAbstract(), new Mono($data['description'])));
		$metadata["IPTC:Caption-Abstract"] = $data['description'];
		
	}
	// WebStatement
	if(isset($data['webstatement'])){
		// XMP
		$bag->add(new Metadata(new WebStatement(), new Mono($data['webstatement'])));
		$metadata["XMP-xmpRights:WebStatement"] = $data['webstatement'];
	}
	// Licensor URL
	if(isset($data['licensor_url'])){
		// XMP
		$bag->add(new Metadata(new LicensorURL(), new Mono($data['licensor_url'])));
		$metadata["XMP-plus:LicensorURL"] = $data['licensor_url'];
	}
	// Copyright
	if(isset($data['copyright_notice'])){
		// XMP
		$bag->add(new Metadata(new Rights(), new Mono($data['copyright_notice'])));
		$metadata["XMP-dc:Rights"] = $data['copyright_notice'];
		
		// IPTC
		$bag->add(new Metadata(new CopyrightNotice(), new Mono($data['copyright_notice'])));
		$metadata["IPTC:CopyrightNotice"] = $data['copyright_notice'];
	}
	// Credit
	if(isset($data['credit'])){
		// XMP
		$bag->add(new Metadata(new XMPCredit(), new Mono($data['credit'])));
		$metadata["XMP-photoshop:Credit"] = $data['credit'];
		
		// IPTC
		$bag->add(new Metadata(new Credit(), new Mono($data['credit'])));
		$metadata["IPTC:Credit"] = $data['credit'];
	}
	// Creator
	if(isset($data['creator'])){
		
		// XMP
		$bag->add(new Metadata(new Creator(), new Mono($data['creator'])));
		$metadata["XMP-dc:Creator"] = $data['creator'];
				
		// IPTC
		$bag->add(new Metadata(new ByLine(), new Mono($data['creator'])));
		$metadata["IPTC:By-line"] = $data['creator'];
	}
	// Keywords
	if(isset($data['keywords'])){
		
		// XMP
		$bag->add(new Metadata(new Subject(), new Mono($data['keywords'])));
		$metadata["XMP-dc:Subject"] = $data['keywords'];
		
		// IPTC
		$bag->add(new Metadata(new IPTC_Keywords(), new Mono($data['keywords'])));
		$metadata["IPTC:Keywords"] = $data['keywords'];
	}
	// ModifyDate
	if(isset($data['IFD0:ModifyDate'])){
		// ModifyDate
		$bag->add(new Metadata(new ModifyDate(), new Mono($data['IFD0:ModifyDate'])));
		$metadata["IFD0:ModifyDate"] = $data['IFD0:ModifyDate'];
	}
	if(isset($data['ExifIFD:ExifVersion'])){
		// ExifVersion
		$bag->add(new Metadata(new ExifVersion(), new Mono($data['ExifIFD:ExifVersion'])));
		$metadata["ExifIFD:ExifVersion"] = $data['ExifIFD:ExifVersion'];
	}
	if(isset($data['ExifIFD:DateTimeOriginal'])){
		// DateTimeOriginal
		$bag->add(new Metadata(new DateTimeOriginal(), new Mono($data['ExifIFD:DateTimeOriginal'])));
		$metadata["ExifIFD:DateTimeOriginal"] = $data['ExifIFD:DateTimeOriginal'];
	}
	if(isset($data['ExifIFD:CreateDate'])){
		// CreateDate
		$bag->add(new Metadata(new CreateDate(), new Mono($data['ExifIFD:CreateDate'])));
		$metadata["ExifIFD:CreateDate"] = $data['ExifIFD:CreateDate'];
	}
	if(isset($data['ExifIFD:OffsetTimeOriginal'])){
		// OffsetTimeOriginal
		$bag->add(new Metadata(new OffsetTimeOriginal(), new Mono($data['ExifIFD:OffsetTimeOriginal'])));
		$metadata["ExifIFD:OffsetTimeOriginal"] = $data['ExifIFD:OffsetTimeOriginal'];
	}
	if(isset($data['ExifIFD:OffsetTimeDigitized'])){
		// OffsetTimeDigitized
		$bag->add(new Metadata(new OffsetTimeDigitized(), new Mono($data['ExifIFD:OffsetTimeDigitized'])));
		$metadata["ExifIFD:OffsetTimeDigitized"] = $data['ExifIFD:OffsetTimeDigitized'];
	}
    
	/*if(isset($data['File:ImageWidth'])){
		// ImageWidth
		$bag->add(new Metadata(new ImageWidth(), new Mono($data['File:ImageWidth'])));
		$metadata["File:ImageWidth"] = $data['File:ImageWidth'];
	}
	if(isset($data['File:ImageHeight'])){
		// ImageHeight
		$bag->add(new Metadata(new ImageHeight(), new Mono($data['File:ImageHeight'])));
		$metadata["File:ImageHeight"] = $data['File:ImageHeight'];
	}*/
    
	if(isset($data['ExifIFD:OffsetTime'])){
		// OffsetTime
		$bag->add(new Metadata(new OffsetTime(), new Mono($data['ExifIFD:OffsetTime'])));
		$metadata["ExifIFD:OffsetTime"] = $data['ExifIFD:OffsetTime'];
	}
	if(isset($data['ExifIFD:ComponentsConfiguration'])){
		// ComponentsConfiguration
		$bag->add(new Metadata(new ComponentsConfiguration(), new Mono($data['ExifIFD:ComponentsConfiguration'])));
		$metadata["ExifIFD:ComponentsConfiguration"] = $data['ExifIFD:ComponentsConfiguration'];
	}
	if(isset($data['ExifIFD:FlashpixVersion'])){
		// FlashpixVersion
		$bag->add(new Metadata(new FlashpixVersion(), new Mono($data['ExifIFD:FlashpixVersion'])));
		$metadata["ExifIFD:FlashpixVersion"] = $data['ExifIFD:FlashpixVersion'];
	}
	if(isset($data['ExifIFD:ColorSpace'])){
		// ColorSpace
		$bag->add(new Metadata(new ColorSpace(), new Mono($data['ExifIFD:ColorSpace'])));
		$metadata["ExifIFD:ColorSpace"] = $data['ExifIFD:ColorSpace'];
	}
	
	
	// Apply to all attachments
	if(!empty($attachment_id)){
		
		if($scaled_only){
			$all_sizes = wpclink__get_scaled_image_only($attachment_id);
		}else{
		// All
			$all_sizes = wpclink_get_all_image_sizes($attachment_id);
		}
		foreach($all_sizes as $single_image){
			$writer->write($single_image, $bag);
		}
		
	}else{
		$writer->write($image_path, $bag);
	}
	
	
	// Cache
	if($cache_id > 0){
				
		if(is_array($metadata)){
			
			// Cache
			if($prev_metadata = get_post_meta($cache_id,'wpclink_media_cache_metadata',true)){
				if(is_array($prev_metadata)){
					// Update Existing Data
					$updated_data = array_replace($prev_metadata,$metadata);
					// Update
					update_post_meta($cache_id,'wpclink_media_cache_metadata',$updated_data);
				}
			}else{
				update_post_meta($cache_id,'wpclink_media_cache_metadata',$metadata);
			}
		}
	}
}
/**
 * CLink Get Exif Tool Image Medatadata 
 * 
 * @param string path image path
 * @param array field metadata fields
 *
 * @return string matadata tag 
 */
function wpclink_get_image_all_metadata_value($path = false){
	
$logger = new Logger('exiftool');
$reader = Reader::create($logger);
$metadataBag = $reader->files($path)->first();

foreach ($metadataBag as $metadata) {
	
    if (ValueInterface::TYPE_BINARY === $metadata->getValue()->getType()) {		

	$key_tag = (string)$metadata->getTag();
	$tags[$key_tag] = $metadata->getValue()->asString();
		
    } else {

	$key_tag = (string)$metadata->getTag();
	$tags[$key_tag] = $metadata->getValue()->asString();
			
		
    }
	
}
	return $tags;
	
}
/**
 * CLink Get Exif Tool Image Medatadata 
 * 
 * @param string path image path
 * @param array field metadata fields
 *
 * @return string matadata tag 
 */
function wpclink_get_image_metadata_value($path = false, $field = ''){
	
$logger = new Logger('exiftool');
$reader = Reader::create($logger);
$metadataBag = $reader->files($path)->first();
if(is_array($field)){
	$tags = array();
}else{
	$tags = '';
}
	
foreach ($metadataBag as $metadata) {
	
    if (ValueInterface::TYPE_BINARY === $metadata->getValue()->getType()) {
		
		if(is_array($field)){
			if(in_array($metadata->getTag(), $field)){
				$key_tag = (string)$metadata->getTag();
				$tags[$key_tag] = $metadata->getValue()->asString();
			}
		}else{
			if($metadata->getTag() == $field){
				return $metadata->getValue()->asString();
			}
		}
		
    } else {
		
		if(is_array($field)){
			
			if(in_array($metadata->getTag(), $field)){
				$key_tag = (string)$metadata->getTag();
				$tags[$key_tag] = $metadata->getValue()->asString();
			}
		}else{
			if($metadata->getTag() == $field){
				return $metadata->getValue()->asString();
			}
		}
    }
	
}
	return $tags;
	
}
/**
 * CLink Exif Read XMP Metadata
 * 
 * @param string tag 
 * @param string image_path path of image 
 * 
 */
function wpclink_exif_read_xmp_metadata($tag = 'provenance', $image_path = ''){
	
	
	$exiftool_file = dirname (WPCLINK_MAIN_FILE) . '/vendor/phpexiftool/exiftool/exiftool';
	$output = shell_exec('perl '.$exiftool_file.' -struct -j -xmp:'.$tag.' '.$image_path);
	$xmp_provenance_array = json_decode($output, true);
	foreach ($xmp_provenance_array  as $xmp_provenance){
		foreach ($xmp_provenance as $key => $single){
			if($key == 'Provenance'){
				return $single;
			}
		}
	}
	return false;
}